@@ -305,7 +305,7 @@ char* show_new_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent) {
 			if ((index = gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box))) != -1) {
 #endif
 				provider = providers_list[index];
-				text = g_strconcat(publisher, ":", provider, NULL);
+				text = g_strconcat(publisher, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_STRING, provider, NULL);
 				if (create_new_publisher(subscriber, new_dialog, text)) {
 					new_publisher = text;
 				} else {
