@@ -76,10 +76,10 @@ static void item_added(MicrofeedSubscriber* subscriber, const char* publisher, c
 		printf("    %s: %s\n", key, value);
 	}
 	if ((value = microfeed_item_get_property(item, "content.image"))) {
-		microfeed_subscriber_send_item_data(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, value, NULL, NULL);
+//		microfeed_subscriber_send_item_data(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, value, NULL, NULL);
 	}
 	if ((value = microfeed_item_get_property(item, "sender.image"))) {
-		microfeed_subscriber_send_item_data(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, value, NULL, NULL);
+//		microfeed_subscriber_send_item_data(subscriber, publisher, MICROFEED_FEED_URI_IMAGES, value, NULL, NULL);
 	}
 	
 	microfeed_item_iterator_free(iterator);
@@ -120,10 +120,11 @@ static void item_removed(MicrofeedSubscriber* subscriber, const char* publisher,
 static void item_status_changed(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const MicrofeedItemStatus status, void* user_data) {
 	printf("Status changed: %s %s %s %u\n", publisher, uri, uid, (unsigned int)status);
 }
-
+/*
 static void item_data_received(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const void* data, const size_t length, void* user_data) {
 	printf("Data: %s %s %s (length: %u)\n", publisher, uri, uid, length);
 }
+*/
 
 static MicrofeedSubscriberCallbacks callbacks = {
 	error_occured,
@@ -136,7 +137,6 @@ static MicrofeedSubscriberCallbacks callbacks = {
 	item_republished,
 	item_removed,
 	item_status_changed,
-	item_data_received
 };
 
 int main(int argc, char** argv) {
